@@ -8,10 +8,11 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: apply.py 7365 2010-08-25 15:41:20Z pjkersha $"
+__revision__ = "$Id: apply.py 7668 2010-10-28 15:39:24Z pjkersha $"
 from ndg.xacml.utils import TypedList
 from ndg.xacml.core.expression import Expression
-from ndg.xacml.core.functions import (FunctionMap, UnsupportedStdFunctionError,
+from ndg.xacml.core.functions import (FunctionMap, functionMap,
+                                      UnsupportedStdFunctionError,
                                       UnsupportedFunctionError)
 
 
@@ -52,7 +53,7 @@ class Apply(Expression):
         super(Apply, self).__init__()
         self.__functionId = None
         self.__function = None
-        self.__functionMap = FunctionMap()
+        self.__functionMap = functionMap
         self.__loadFunctionFromId = True
         self.__expressions = TypedList(Expression)
       
