@@ -8,7 +8,7 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: attributevalue.py 7412 2010-09-02 08:25:48Z pjkersha $"
+__revision__ = "$Id: attributevalue.py 7682 2010-11-01 16:30:22Z pjkersha $"
 from datetime import datetime, timedelta
 
 from ndg.xacml.utils import VettedDict
@@ -149,7 +149,7 @@ class AttributeValue(Expression):
 
     def __repr__(self):
         return "%s = %r " % (super(AttributeValue, self).__repr__(),
-                             self.__value)
+                             self.value)
 
     def __eq__(self, attrVal):
         """Check for equality by comparing the value attributes"""
@@ -240,25 +240,10 @@ class AttributeValueClassMap(VettedDict):
         return True 
 
 
-# Dynamically Create classes based on AttributeValue for all the XACML primitive
-# types
-_IDENTIFIER2CLASS_MAP = AttributeValueClassMap()
-
-for typeName, _type in AttributeValue.TYPE_MAP.items():
-    identifier = AttributeValue.TYPE_URI_MAP[typeName]
-
-    className = typeName + AttributeValue.CLASS_NAME_SUFFIX               
-    classVars = {'TYPE': _type, 'IDENTIFIER': identifier}
-    
-    attributeValueClass = type(className, (AttributeValue, ), classVars)
-    AttributeValue.register(attributeValueClass)
-    _IDENTIFIER2CLASS_MAP[identifier] = attributeValueClass
-    
-    
 class AttributeValueClassFactory(object):
     """Create AttributeValue types based on the XML namespace identifier
     
-    Convenience wrapper for _IDENTIFIER2CLASS_MAP instance of 
+    Convenience wrapper for IDENTIFIER2CLASS_MAP instance of 
     AttributeValueClassMap
     
     @ivar __classMap: mapping object to map attribute value URIs to their 
@@ -267,16 +252,35 @@ class AttributeValueClassFactory(object):
     """
     __slots__ = ('__classMap',)
     
+    # Dynamically Create classes based on AttributeValue for all the XACML 
+    # primitive types
+    IDENTIFIER2CLASS_MAP = AttributeValueClassMap()
+    _typeName, _type, _identifier, _className, _classVars, \
+        _attributeValueClass = (None,)*6
+        
+    for _typeName, _type in AttributeValue.TYPE_MAP.items():
+        _identifier = AttributeValue.TYPE_URI_MAP[_typeName]
+    
+        _className = _typeName + AttributeValue.CLASS_NAME_SUFFIX               
+        _classVars = {'TYPE': _type, 'IDENTIFIER': _identifier}
+        
+        _attributeValueClass = type(_className, (AttributeValue, ), _classVars)
+        AttributeValue.register(_attributeValueClass)
+        IDENTIFIER2CLASS_MAP[_identifier] = _attributeValueClass
+    
+    del _typeName, _type, _identifier, _className, _classVars, \
+        _attributeValueClass
+        
     def __init__(self, classMap=None):
         """Set a mapping object to map attribute value URIs to their 
         implementations as classes
         
         @param classMap: input an alternative to the default class mapping 
-        object _IDENTIFIER2CLASS_MAP, if None, it will default to this setting
+        object IDENTIFIER2CLASS_MAP, if None, it will default to this setting
         @type classMap: ndg.xacml.core.attributevalue.AttributeValueClassMap
         """
         if classMap is None:
-            self.__classMap = _IDENTIFIER2CLASS_MAP
+            self.__classMap = self.__class__.IDENTIFIER2CLASS_MAP
         elif isinstance(classMap, AttributeValueClassMap):
             self.__classMap = classMap
         else:
@@ -292,4 +296,28 @@ class AttributeValueClassFactory(object):
         type
         """
         return self.__classMap.get(identifier)
-        
\ No newline at end of file
+    
+    @classmethod
+    def addClass(cls, identifier, attributeValueClass, overwrite=False):
+        """Extend Default AttributeValue Class Map with custom types.  This 
+        enables the policy to support additional attribute types
+        
+        @param identifier: ID for candidate Attribute Value class
+        @type identifier: ndg.xacml.core.attributevalue.AttributeValueClassMap 
+        @param attributeValueClass: new Attribute Value class to be added
+        @type attributeValueClass: ndg.xacml.core.attributevalue.AttributeValue
+        @param overwrite: set to True to allow overwriting of existing map 
+        entries, defaults to disable overwrite
+        @type overwrite: bool
+        """
+        # Instantiate class map to validate input types.
+        classMap = AttributeValueClassMap()
+        classMap[identifier] = attributeValueClass
+        
+        if overwrite:
+            cls.IDENTIFIER2CLASS_MAP.update(classMap)
+        else:
+            for k, v in classMap.items():
+                if k not in cls.IDENTIFIER2CLASS_MAP:
+                    cls.IDENTIFIER2CLASS_MAP[k] = v        
+                    
\ No newline at end of file
