@@ -8,7 +8,7 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: __init__.py 7351 2010-08-20 14:46:35Z pjkersha $"
+__revision__ = "$Id: __init__.py 7682 2010-11-01 16:30:22Z pjkersha $"
 from abc import ABCMeta, abstractmethod
 from datetime import datetime, timedelta
 import traceback
@@ -597,9 +597,8 @@ class FunctionMap(VettedDict):
             
         return True 
            
-    def loadAll(self):
-        """Load function map with implementations from the relevant function
-        package"""
+    def loadAllCore(self):
+        """Load all core XACML functions"""
         
         for functionNs in XacmlFunctionNames.FUNCTION_NAMES:
             self.loadFunction(functionNs)
@@ -611,6 +610,12 @@ class FunctionMap(VettedDict):
         @param functionNs: XACML function namespace
         @type functionNs: basestring
         """
+        # Try map for custom function class
+        if functionNs in self:
+            return self[functionNs]
+        
+        # else try the class factory - there is one factory per family of 
+        # functions e.g. bag functions, at least one member of functions etc.
         functionFactory = self.__classFactoryMap.get(functionNs)
         if functionFactory is not None:
             # Get function class from previously cached factory
@@ -697,5 +702,7 @@ class FunctionMap(VettedDict):
         else:
             return functionClass
 
-
+# Function map singleton used by match and apply classes - add new keys to
+# this dictionary to enable support for custom functions
+functionMap = FunctionMap()
         
\ No newline at end of file
