@@ -8,7 +8,7 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: match.py 7351 2010-08-20 14:46:35Z pjkersha $"
+__revision__ = "$Id: match.py 7668 2010-10-28 15:39:24Z pjkersha $"
 import logging
 log = logging.getLogger(__name__)
 
@@ -16,7 +16,8 @@ from ndg.xacml.core import XacmlCoreBase
 from ndg.xacml.core.attributevalue import AttributeValue
 from ndg.xacml.core.attributedesignator import AttributeDesignator
 from ndg.xacml.core.attributeselector import AttributeSelector
-from ndg.xacml.core.functions import (FunctionMap, UnsupportedStdFunctionError,
+from ndg.xacml.core.functions import (FunctionMap, functionMap,
+                                      UnsupportedStdFunctionError,
                                       UnsupportedFunctionError)
 from ndg.xacml.core.context.exceptions import XacmlContextError
 
@@ -81,7 +82,7 @@ class MatchBase(XacmlCoreBase):
         self.__matchId = None
         
         self.__function = None
-        self.__functionMap = FunctionMap()
+        self.__functionMap = functionMap
         self.__loadFunctionFromId = True
         
     @property
