@@ -8,7 +8,7 @@ __copyright__ = "(C) 2010 Science and Technology Facilities Council"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __license__ = "BSD - see LICENSE file in top-level directory"
 __contact__ = "Philip.Kershaw@stfc.ac.uk"
-__revision__ = "$Id: rule.py 7365 2010-08-25 15:41:20Z pjkersha $"
+__revision__ = "$Id: rule.py 7706 2010-11-05 11:33:22Z pjkersha $"
 import traceback
 import logging
 log = logging.getLogger(__name__)
@@ -389,12 +389,13 @@ class Rule(XacmlCoreBase):
                 decision = Decision(decision=self.effect.value)
             else:
                 decision = Decision.NOT_APPLICABLE
-                
+               
+            log.debug('Rule %r evaluates to %s', self.id, decision) 
             return decision
         
         except Exception, e:
+            _traceback = traceback.format_exc()
             log.error('Error occurred evaluating rule %r, returning '
                       'Indeterminate result to caller: %s',
-                      self.id,
-                      traceback.format_exc())
+                      self.id, _traceback)
             return Decision.INDETERMINATE
